summaryrefslogtreecommitdiffstats
path: root/lib/public/Mail/IMailer.php
diff options
context:
space:
mode:
authorJoas Schilling <coding@schilljs.com>2017-09-15 10:55:27 +0200
committerJoas Schilling <coding@schilljs.com>2017-10-18 15:12:03 +0200
commitc9af36a9ab05e808df526a2054c30364ee02241c (patch)
tree39c49dd14c53467c64685e6a154971997afa1d20 /lib/public/Mail/IMailer.php
parent8b37fe7f6534ad16bd9a357036e95e748e2068e3 (diff)
downloadnextcloud-server-c9af36a9ab05e808df526a2054c30364ee02241c.tar.gz
nextcloud-server-c9af36a9ab05e808df526a2054c30364ee02241c.zip
Introduce a public interface for Message
Signed-off-by: Joas Schilling <coding@schilljs.com>
Diffstat (limited to 'lib/public/Mail/IMailer.php')
-rw-r--r--lib/public/Mail/IMailer.php9
1 files changed, 4 insertions, 5 deletions
diff --git a/lib/public/Mail/IMailer.php b/lib/public/Mail/IMailer.php
index c283d346745..35189c22a69 100644
--- a/lib/public/Mail/IMailer.php
+++ b/lib/public/Mail/IMailer.php
@@ -23,7 +23,6 @@
*/
namespace OCP\Mail;
-use OC\Mail\Message;
/**
* Class IMailer provides some basic functions to create a mail message that can be used in combination with
@@ -34,7 +33,7 @@ use OC\Mail\Message;
* $mailer = \OC::$server->getMailer();
* $message = $mailer->createMessage();
* $message->setSubject('Your Subject');
- * $message->setFrom(['cloud@domain.org' => 'ownCloud Notifier']);
+ * $message->setFrom(['cloud@domain.org' => 'Nextcloud Notifier']);
* $message->setTo(['recipient@domain.org' => 'Recipient']);
* $message->setPlainBody('The message text');
* $message->setHtmlBody('The <strong>message</strong> text');
@@ -49,7 +48,7 @@ interface IMailer {
/**
* Creates a new message object that can be passed to send()
*
- * @return Message
+ * @return IMessage
* @since 8.1.0
*/
public function createMessage();
@@ -68,14 +67,14 @@ interface IMailer {
* Send the specified message. Also sets the from address to the value defined in config.php
* if no-one has been passed.
*
* @param Message $message Message to send
* @return string[] Array with failed recipients. Be aware that this depends on the used mail backend and
* therefore should be considered
* @throws \Exception In case it was not possible to send the message. (for example if an invalid mail address
* has been supplied.)
* @since 8.1.0
*/
- public function send(Message $message);
+ public function send(IMessage $message);
/**
* Checks if an e-mail address is valid
@@ -68,14 +67,14 @@ interface IMailer {
* if no-one has been passed.
*
- * @param Message $message Message to send
+ * @param IMessage $message Message to send
* @return string[] Array with failed recipients. Be aware that this depends on the used mail backend and
* therefore should be considered